#' Cherry Ripe weights
#'
#' The weight of 'Fun Size' Cherry Ripe chocolate bars.
#' 
#' @docType data
#' 
#' @keywords datasets
#'
#' @format A data frame with 16 rows (each combination of the other variables)
#'  and 4 columns:
#' \describe{
#'   \item{TotalWeight}{The weight of the wrapper bar, in g}
#'   \item{WrapperWt}{The weight of the wrapper only, in g}
#'   \item{BarWt}{The weight of the chocolate bar itself, in g, by subtraction}
#'   \item{Year}{The year, from 2011, 2013 to 2015, 2017 to 2019}
#' }
#' 
#' @details
#' The Cherry Ripe chocolate bars were weighted as an in-class activity, 
#' usually by weighing the bar+wrapper, and then the wrapper 
#' (for hygiene reasons) on a set of scales.
#' The bars were in a Fun Size pack, of about 11 bars.
#' Until 2015, the weights were listed in the nutrition panel as 18g.
#' After 2015, this changed to 14g.
#' 
#' @source 
#' Collected and weighed by Peter K. Dunn and students (who got to eat the
#' chocolate bars).
#' 
#' @usage 
#' data(CherryRipe)
#' 
#' @examples
#' plot(BarWt ~ factor(Year), data = CherryRipe, xlab = "Year", ylab = "Bar weight (g)")
#' 

"CherryRipe"
