#' Wheelchair tennis
#'
#' The push time for wheelchair tennis players, with and without holding a racquet.
#' 
#' 
#' @docType data
#' 
#' @keywords datasets
#'
#' @format A data frame with 13 rows (each player) and 3 columns:
#' \describe{
#'   \item{Person}{The person}
#'   \item{PTwith}{The push time, when holding a racquet; in seconds}
#'   \item{PTwithout}{The push time, without holding a racquet; in seconds}
#' }
#' 
#' @source 
#' I. Alberca, 2016, 
#' Kinetic and temporal parameters calculated from raw data collected via 
#' wireless instrumented wheel for measuring 3D pushrim kinetics of 
#' a racing wheelchair,
#'  https://doi.org/10.17026/dans-xjf-bs8v, 
#'  \emph{DANS Data Station Life Sciences}, V1.
#'  
#' @references
#' Alberca, I., Chénier, F., Astier, M., Watelain, E., Vallier, J. M., Pradon, D., & Faupin, A. (2022). 
#' Sprint performance and force application of tennis players during manual
#'  wheelchair propulsion with and without holding a tennis racket. 
#' \emph{PLoS ONE}, \bold{17}(2), e0263392.
#' 
#' 
#' @usage 
#' data(WCTennis)
#' 
#' @examples
#' with(WCTennis, hist(PTwithout - PTwith), xlab="Pushtime increase without racquet")
#' 

"WCTennis"
